@@ -3,7 +3,7 @@ package Net::Async::Redis::Cluster::XS;
 use strict;
 use warnings;
 
-our $VERSION = '0.012'; # VERSION
+our $VERSION = '0.013'; # VERSION
 
 use parent qw(Net::Async::Redis::Cluster);
 
@@ -36,7 +36,11 @@ async sub bootstrap {
             )
         );
         await $redis->connect;
-        await $self->apply_slots_from_instance($redis);
+        await $self->apply_slots_from_instance(
+            $redis,
+            host => $args{host},
+            port => $args{port}
+        );
     } finally {
         $redis->remove_from_parent if $redis;
     }
